# Example to create force constants using MLPs by pypolymlp

This is an example to follow the documentation
https://phonopy.github.io/phono3py/pypolymlp.html.
`phono3py_params.yaml` can be also generated by

```bash
% python make_phono3py_params.py ../NaCl-rd/phono3py_params_NaCl.yaml.xz
```
